<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked EditPage class.
 *
 * $Horde: wicked/lib/Page/EditPage.php,v 1.21 2005/08/24 05:19:52 selsky Exp $
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @package Wicked
 */
class EditPage extends Page {

    /**
     * Display modes supported by this page.
     *
     * @var array
     */
    var $supportedModes = array(
        WICKED_MODE_DISPLAY => true,
        WICKED_MODE_EDIT => true);

    /**
     * The page that we're displaying backlinks to.
     *
     * @var string
     */
    var $_referrer = null;

    function EditPage($referrer)
    {
        $this->_referrer = $referrer;
    }

    /**
     * Retrieve this user's permissions for the referring page.
     *
     * @return integer  The permissions bitmask.
     */
    function getPermissions()
    {
        return parent::getPermissions($this->referrer());
    }

    /**
     * Send them back whence they came if they aren't allowed to edit
     * this page.
     */
    function preDisplay()
    {
        if (!$this->allows(WICKED_MODE_EDIT)) {
            header('Location: ' . Wicked::url($this->referrer(), true));
            exit;
        }
    }

    /**
     * Render this page in Display mode.
     *
     * @return mixed                Returns true or PEAR_Error.
     */
    function display()
    {
        $page = &Page::getPage($this->referrer());
        $page_text = Util::getFormData('page_text');
        if (is_null($page_text)) {
            $page_text = $page->getText();
        }

        require WICKED_TEMPLATES . '/edit/standard.inc';
        return true;
    }

    function pageName()
    {
        return 'EditPage';
    }

    function pageTitle()
    {
        return _("EditPage");
    }

    function referrer()
    {
        return $this->_referrer;
    }

    function handleAction()
    {
        global $notification, $conf;

        if (!$this->allows(WICKED_MODE_EDIT)) {
            $notification->push(sprintf(_("You don't have permission to edit \"%s\"."), $page->pageName()));
        } else {
            $page = &Page::getPage($this->referrer());
            $text = Util::getFormData('page_text');
            $changelog = Util::getFormData('changelog');
            if ($conf['wicked']['require_change_log'] && empty($changelog)) {
                $notification->push(_("You must enter a change description to save the page."), 'horde.error');
                return;
            }
            $minorchange = Util::getFormData('minor');
            if (trim($text) == trim($page->getText())) {
                $notification->push(_("No changes made"), 'horde.warning');
            } else {
                $result = $page->updateText($text, $changelog, $minorchange);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(sprintf(_("Save Failed: %s"),
                                                $result->getMessage()), 'horde.error');
                } else {
                    $notification->push(_("Page Saved"), 'horde.success');
                }
            }
        }

        // Show the newly saved page.
        header('Location: ' . Wicked::url($this->referrer(), true));
        exit;
    }

}
