<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked PageSearch class.
 *
 * $Horde: wicked/lib/Page/PageSearch.php,v 1.8 2005/06/23 02:55:36 selsky Exp $
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @package Wicked
 */
class PageSearch extends Page {

    /**
     * Display modes supported by this page.
     *
     * @var array
     */
    var $supportedModes = array(
        WICKED_MODE_CONTENT => true,
        WICKED_MODE_DISPLAY => true);

    /**
     * Cached search results.
     *
     * @var array
     */
    var $_results;

    /**
     * Render this page in Content mode.
     *
     * @param string $searchtext  The title to search for.
     *
     * @return string  The page content, or PEAR_Error.
     */
    function content($searchtext = '')
    {
        global $wicked;

        if (empty($searchtext)) {
            return array();
        }

        return $wicked->searchText($searchtext);
    }

    /**
     * Perform any pre-display checks for permissions, searches,
     * etc. Called before any output is sent so the page can do
     * redirects. If the page wants to take control of flow from here,
     * it can, and is entirely responsible for handling the user
     * (should call exit after redirecting, for example).
     *
     * $param integer $mode    The page render mode.
     * $param array   $params  Any page parameters.
     */
    function preDisplay($mode, $params)
    {
        $this->_results = $this->content($params);
        if (!is_a($this->_results, 'PEAR_Error') &&
            count($this->_results) == 1) {
            // Only one result, go right there.
            header('Location: ' . Wicked::url($this->_results[0]['page_name'], true));
            exit;
        }
    }

    /**
     * Render this page in Display mode.
     *
     * @param string $searchtext  The title to search for.
     *
     * @return mixed  Returns true or PEAR_Error.
     */
    function display($searchtext = '')
    {
        global $notification;

        $this->_results = $this->content($searchtext);
        if (is_a($this->_results, 'PEAR_Error')) {
            $notification->push('Error retrieving search results: ' .
                                $this->_results->getMessage(), 'horde.error');
            return $this->_results;
        }

        require_once 'Horde/Template.php';
        $template = &new Horde_Template();
        $pages = array();
        foreach ($this->_results as $page) {
            if (!empty($page['page_history'])) {
                $page = &new StdHistoryPage($page);
            } else {
                $page = &new StandardPage($page);
            }

            $pages[] = array('author' => $page->author(),
                             'created' => $page->formatVersionCreated(),
                             'name' => $page->pageName(),
                             'url' => $page->pageUrl(),
                             'version' => $page->version());
        }
        $template->set('pages', $pages);
        $template->set('hits', false, true);

        // Show search form and page header.
        require WICKED_TEMPLATES . '/pagelist/pagesearch.inc';
        echo $template->fetch(WICKED_TEMPLATES . '/pagelist/pagelist.html');
        require WICKED_TEMPLATES . '/pagelist/footer.inc';
        return true;
    }

    function pageName()
    {
        return 'PageSearch';
    }

    function pageTitle()
    {
        return _("PageSearch");
    }

}
